notify

package
v1.24.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 13, 2026 License: AGPL-3.0 Imports: 3 Imported by: 0

Documentation

Overview

Package notify provides desktop notifications for polycode. Uses osascript on macOS and notify-send on Linux.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Available

func Available() bool

Available returns true if desktop notifications are supported on this platform.

func Send

func Send(title, body string) error

Send sends a desktop notification with the given title and body. Returns nil if notifications are not available on the platform.

Types

This section is empty.

Jump to